worker

package
v1.62.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2026 License: MIT Imports: 10 Imported by: 6

Documentation

Overview

Code generated by protoc-gen-go-helpers. DO NOT EDIT.

Index

Constants

This section is empty.

Variables

var File_temporal_api_worker_v1_message_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type PluginInfo added in v1.51.0

type PluginInfo struct {

	// The name of the plugin, required.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The version of the plugin, may be empty.
	Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

func (*PluginInfo) Descriptor deprecated added in v1.51.0

func (*PluginInfo) Descriptor() ([]byte, []int)

Deprecated: Use PluginInfo.ProtoReflect.Descriptor instead.

func (*PluginInfo) Equal added in v1.51.0

func (this *PluginInfo) Equal(that interface{}) bool

Equal returns whether two PluginInfo values are equivalent by recursively comparing the message's fields. For more information see the documentation for https://pkg.go.dev/google.golang.org/protobuf/proto#Equal

func (*PluginInfo) GetName added in v1.51.0

func (x *PluginInfo) GetName() string

func (*PluginInfo) GetVersion added in v1.51.0

func (x *PluginInfo) GetVersion() string

func (*PluginInfo) Marshal added in v1.51.0

func (val *PluginInfo) Marshal() ([]byte, error)

Marshal an object of type PluginInfo to the protobuf v3 wire format

func (*PluginInfo) ProtoMessage added in v1.51.0

func (*PluginInfo) ProtoMessage()

func (*PluginInfo) ProtoReflect added in v1.51.0

func (x *PluginInfo) ProtoReflect() protoreflect.Message

func (*PluginInfo) Reset added in v1.51.0

func (x *PluginInfo) Reset()

func (*PluginInfo) Size added in v1.51.0

func (val *PluginInfo) Size() int

Size returns the size of the object, in bytes, once serialized

func (*PluginInfo) String added in v1.51.0

func (x *PluginInfo) String() string

func (*PluginInfo) Unmarshal added in v1.51.0

func (val *PluginInfo) Unmarshal(buf []byte) error

Unmarshal an object of type PluginInfo from the protobuf v3 wire format

type StorageDriverInfo added in v1.62.3

type StorageDriverInfo struct {

	// The type of the driver, required.
	Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	// contains filtered or unexported fields
}

func (*StorageDriverInfo) Descriptor deprecated added in v1.62.3

func (*StorageDriverInfo) Descriptor() ([]byte, []int)

Deprecated: Use StorageDriverInfo.ProtoReflect.Descriptor instead.

func (*StorageDriverInfo) Equal added in v1.62.3

func (this *StorageDriverInfo) Equal(that interface{}) bool

Equal returns whether two StorageDriverInfo values are equivalent by recursively comparing the message's fields. For more information see the documentation for https://pkg.go.dev/google.golang.org/protobuf/proto#Equal

func (*StorageDriverInfo) GetType added in v1.62.3

func (x *StorageDriverInfo) GetType() string

func (*StorageDriverInfo) Marshal added in v1.62.3

func (val *StorageDriverInfo) Marshal() ([]byte, error)

Marshal an object of type StorageDriverInfo to the protobuf v3 wire format

func (*StorageDriverInfo) ProtoMessage added in v1.62.3

func (*StorageDriverInfo) ProtoMessage()

func (*StorageDriverInfo) ProtoReflect added in v1.62.3

func (x *StorageDriverInfo) ProtoReflect() protoreflect.Message

func (*StorageDriverInfo) Reset added in v1.62.3

func (x *StorageDriverInfo) Reset()

func (*StorageDriverInfo) Size added in v1.62.3

func (val *StorageDriverInfo) Size() int

Size returns the size of the object, in bytes, once serialized

func (*StorageDriverInfo) String added in v1.62.3

func (x *StorageDriverInfo) String() string

func (*StorageDriverInfo) Unmarshal added in v1.62.3

func (val *StorageDriverInfo) Unmarshal(buf []byte) error

Unmarshal an object of type StorageDriverInfo from the protobuf v3 wire format

type WorkerHeartbeat

type WorkerHeartbeat struct {

	// Worker identifier, should be unique for the namespace.
	// It is distinct from worker identity, which is not necessarily namespace-unique.
	WorkerInstanceKey string `protobuf:"bytes,1,opt,name=worker_instance_key,json=workerInstanceKey,proto3" json:"worker_instance_key,omitempty"`
	// Worker identity, set by the client, may not be unique.
	// Usually host_name+(user group name)+process_id, but can be overwritten by the user.
	WorkerIdentity string `protobuf:"bytes,2,opt,name=worker_identity,json=workerIdentity,proto3" json:"worker_identity,omitempty"`
	// Worker host information.
	HostInfo *WorkerHostInfo `protobuf:"bytes,3,opt,name=host_info,json=hostInfo,proto3" json:"host_info,omitempty"`
	// Task queue this worker is polling for tasks.
	TaskQueue         string                      `protobuf:"bytes,4,opt,name=task_queue,json=taskQueue,proto3" json:"task_queue,omitempty"`
	DeploymentVersion *v1.WorkerDeploymentVersion `protobuf:"bytes,5,opt,name=deployment_version,json=deploymentVersion,proto3" json:"deployment_version,omitempty"`
	SdkName           string                      `protobuf:"bytes,6,opt,name=sdk_name,json=sdkName,proto3" json:"sdk_name,omitempty"`
	SdkVersion        string                      `protobuf:"bytes,7,opt,name=sdk_version,json=sdkVersion,proto3" json:"sdk_version,omitempty"`
	// Worker status. Defined by SDK.
	Status v11.WorkerStatus `protobuf:"varint,8,opt,name=status,proto3,enum=temporal.api.enums.v1.WorkerStatus" json:"status,omitempty"`
	// Worker start time.
	// It can be used to determine worker uptime. (current time - start time)
	StartTime *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// Timestamp of this heartbeat, coming from the worker. Worker should set it to "now".
	// Note that this timestamp comes directly from the worker and is subject to workers' clock skew.
	HeartbeatTime *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=heartbeat_time,json=heartbeatTime,proto3" json:"heartbeat_time,omitempty"`
	// Elapsed time since the last heartbeat from the worker.
	ElapsedSinceLastHeartbeat *durationpb.Duration `` /* 141-byte string literal not displayed */
	WorkflowTaskSlotsInfo     *WorkerSlotsInfo     `` /* 129-byte string literal not displayed */
	ActivityTaskSlotsInfo     *WorkerSlotsInfo     `` /* 129-byte string literal not displayed */
	NexusTaskSlotsInfo        *WorkerSlotsInfo     `protobuf:"bytes,14,opt,name=nexus_task_slots_info,json=nexusTaskSlotsInfo,proto3" json:"nexus_task_slots_info,omitempty"`
	LocalActivitySlotsInfo    *WorkerSlotsInfo     `` /* 132-byte string literal not displayed */
	WorkflowPollerInfo        *WorkerPollerInfo    `protobuf:"bytes,16,opt,name=workflow_poller_info,json=workflowPollerInfo,proto3" json:"workflow_poller_info,omitempty"`
	WorkflowStickyPollerInfo  *WorkerPollerInfo    `` /* 138-byte string literal not displayed */
	ActivityPollerInfo        *WorkerPollerInfo    `protobuf:"bytes,18,opt,name=activity_poller_info,json=activityPollerInfo,proto3" json:"activity_poller_info,omitempty"`
	NexusPollerInfo           *WorkerPollerInfo    `protobuf:"bytes,19,opt,name=nexus_poller_info,json=nexusPollerInfo,proto3" json:"nexus_poller_info,omitempty"`
	// A Workflow Task found a cached Workflow Execution to run against.
	TotalStickyCacheHit int32 `protobuf:"varint,20,opt,name=total_sticky_cache_hit,json=totalStickyCacheHit,proto3" json:"total_sticky_cache_hit,omitempty"`
	// A Workflow Task did not find a cached Workflow execution to run against.
	TotalStickyCacheMiss int32 `` /* 127-byte string literal not displayed */
	// Current cache size, expressed in number of Workflow Executions.
	CurrentStickyCacheSize int32 `` /* 133-byte string literal not displayed */
	// Plugins currently in use by this SDK.
	Plugins []*PluginInfo `protobuf:"bytes,23,rep,name=plugins,proto3" json:"plugins,omitempty"`
	// Storage drivers in use by this SDK.
	Drivers []*StorageDriverInfo `protobuf:"bytes,24,rep,name=drivers,proto3" json:"drivers,omitempty"`
	// contains filtered or unexported fields
}

Worker info message, contains information about the worker and its current state. All information is provided by the worker itself. (-- api-linter: core::0140::prepositions=disabled

aip.dev/not-precedent: Removing those words make names less clear. --)

func (*WorkerHeartbeat) Descriptor deprecated

func (*WorkerHeartbeat) Descriptor() ([]byte, []int)

Deprecated: Use WorkerHeartbeat.ProtoReflect.Descriptor instead.

func (*WorkerHeartbeat) Equal

func (this *WorkerHeartbeat) Equal(that interface{}) bool

Equal returns whether two WorkerHeartbeat values are equivalent by recursively comparing the message's fields. For more information see the documentation for https://pkg.go.dev/google.golang.org/protobuf/proto#Equal

func (*WorkerHeartbeat) GetActivityPollerInfo

func (x *WorkerHeartbeat) GetActivityPollerInfo() *WorkerPollerInfo

func (*WorkerHeartbeat) GetActivityTaskSlotsInfo

func (x *WorkerHeartbeat) GetActivityTaskSlotsInfo() *WorkerSlotsInfo

func (*WorkerHeartbeat) GetCurrentStickyCacheSize

func (x *WorkerHeartbeat) GetCurrentStickyCacheSize() int32

func (*WorkerHeartbeat) GetDeploymentVersion

func (x *WorkerHeartbeat) GetDeploymentVersion() *v1.WorkerDeploymentVersion

func (*WorkerHeartbeat) GetDrivers added in v1.62.3

func (x *WorkerHeartbeat) GetDrivers() []*StorageDriverInfo

func (*WorkerHeartbeat) GetElapsedSinceLastHeartbeat

func (x *WorkerHeartbeat) GetElapsedSinceLastHeartbeat() *durationpb.Duration

func (*WorkerHeartbeat) GetHeartbeatTime

func (x *WorkerHeartbeat) GetHeartbeatTime() *timestamppb.Timestamp

func (*WorkerHeartbeat) GetHostInfo

func (x *WorkerHeartbeat) GetHostInfo() *WorkerHostInfo

func (*WorkerHeartbeat) GetLocalActivitySlotsInfo

func (x *WorkerHeartbeat) GetLocalActivitySlotsInfo() *WorkerSlotsInfo

func (*WorkerHeartbeat) GetNexusPollerInfo

func (x *WorkerHeartbeat) GetNexusPollerInfo() *WorkerPollerInfo

func (*WorkerHeartbeat) GetNexusTaskSlotsInfo

func (x *WorkerHeartbeat) GetNexusTaskSlotsInfo() *WorkerSlotsInfo

func (*WorkerHeartbeat) GetPlugins added in v1.51.0

func (x *WorkerHeartbeat) GetPlugins() []*PluginInfo

func (*WorkerHeartbeat) GetSdkName

func (x *WorkerHeartbeat) GetSdkName() string

func (*WorkerHeartbeat) GetSdkVersion

func (x *WorkerHeartbeat) GetSdkVersion() string

func (*WorkerHeartbeat) GetStartTime

func (x *WorkerHeartbeat) GetStartTime() *timestamppb.Timestamp

func (*WorkerHeartbeat) GetStatus

func (x *WorkerHeartbeat) GetStatus() v11.WorkerStatus

func (*WorkerHeartbeat) GetTaskQueue

func (x *WorkerHeartbeat) GetTaskQueue() string

func (*WorkerHeartbeat) GetTotalStickyCacheHit

func (x *WorkerHeartbeat) GetTotalStickyCacheHit() int32

func (*WorkerHeartbeat) GetTotalStickyCacheMiss

func (x *WorkerHeartbeat) GetTotalStickyCacheMiss() int32

func (*WorkerHeartbeat) GetWorkerIdentity

func (x *WorkerHeartbeat) GetWorkerIdentity() string

func (*WorkerHeartbeat) GetWorkerInstanceKey

func (x *WorkerHeartbeat) GetWorkerInstanceKey() string

func (*WorkerHeartbeat) GetWorkflowPollerInfo

func (x *WorkerHeartbeat) GetWorkflowPollerInfo() *WorkerPollerInfo

func (*WorkerHeartbeat) GetWorkflowStickyPollerInfo

func (x *WorkerHeartbeat) GetWorkflowStickyPollerInfo() *WorkerPollerInfo

func (*WorkerHeartbeat) GetWorkflowTaskSlotsInfo

func (x *WorkerHeartbeat) GetWorkflowTaskSlotsInfo() *WorkerSlotsInfo

func (*WorkerHeartbeat) Marshal

func (val *WorkerHeartbeat) Marshal() ([]byte, error)

Marshal an object of type WorkerHeartbeat to the protobuf v3 wire format

func (*WorkerHeartbeat) ProtoMessage

func (*WorkerHeartbeat) ProtoMessage()

func (*WorkerHeartbeat) ProtoReflect

func (x *WorkerHeartbeat) ProtoReflect() protoreflect.Message

func (*WorkerHeartbeat) Reset

func (x *WorkerHeartbeat) Reset()

func (*WorkerHeartbeat) Size

func (val *WorkerHeartbeat) Size() int

Size returns the size of the object, in bytes, once serialized

func (*WorkerHeartbeat) String

func (x *WorkerHeartbeat) String() string

func (*WorkerHeartbeat) Unmarshal

func (val *WorkerHeartbeat) Unmarshal(buf []byte) error

Unmarshal an object of type WorkerHeartbeat from the protobuf v3 wire format

type WorkerHostInfo

type WorkerHostInfo struct {

	// Worker host identifier.
	HostName string `protobuf:"bytes,1,opt,name=host_name,json=hostName,proto3" json:"host_name,omitempty"`
	// Worker grouping identifier. A key to group workers that share the same client+namespace+process.
	// This will be used to build the worker command nexus task queue name:
	// "temporal-sys/worker-commands/{worker_grouping_key}"
	WorkerGroupingKey string `protobuf:"bytes,5,opt,name=worker_grouping_key,json=workerGroupingKey,proto3" json:"worker_grouping_key,omitempty"`
	// Worker process identifier. This id only needs to be unique
	// within one host (so using e.g. a unix pid would be appropriate).
	ProcessId string `protobuf:"bytes,2,opt,name=process_id,json=processId,proto3" json:"process_id,omitempty"`
	// System used CPU as a float in the range [0.0, 1.0] where 1.0 is defined as all
	// cores on the host pegged.
	CurrentHostCpuUsage float32 `protobuf:"fixed32,3,opt,name=current_host_cpu_usage,json=currentHostCpuUsage,proto3" json:"current_host_cpu_usage,omitempty"`
	// System used memory as a float in the range [0.0, 1.0] where 1.0 is defined as
	// all available memory on the host is used.
	CurrentHostMemUsage float32 `protobuf:"fixed32,4,opt,name=current_host_mem_usage,json=currentHostMemUsage,proto3" json:"current_host_mem_usage,omitempty"`
	// contains filtered or unexported fields
}

Holds everything needed to identify the worker host/process context

func (*WorkerHostInfo) Descriptor deprecated

func (*WorkerHostInfo) Descriptor() ([]byte, []int)

Deprecated: Use WorkerHostInfo.ProtoReflect.Descriptor instead.

func (*WorkerHostInfo) Equal

func (this *WorkerHostInfo) Equal(that interface{}) bool

Equal returns whether two WorkerHostInfo values are equivalent by recursively comparing the message's fields. For more information see the documentation for https://pkg.go.dev/google.golang.org/protobuf/proto#Equal

func (*WorkerHostInfo) GetCurrentHostCpuUsage

func (x *WorkerHostInfo) GetCurrentHostCpuUsage() float32

func (*WorkerHostInfo) GetCurrentHostMemUsage

func (x *WorkerHostInfo) GetCurrentHostMemUsage() float32

func (*WorkerHostInfo) GetHostName

func (x *WorkerHostInfo) GetHostName() string

func (*WorkerHostInfo) GetProcessId

func (x *WorkerHostInfo) GetProcessId() string

func (*WorkerHostInfo) GetWorkerGroupingKey added in v1.55.0

func (x *WorkerHostInfo) GetWorkerGroupingKey() string

func (*WorkerHostInfo) Marshal

func (val *WorkerHostInfo) Marshal() ([]byte, error)

Marshal an object of type WorkerHostInfo to the protobuf v3 wire format

func (*WorkerHostInfo) ProtoMessage

func (*WorkerHostInfo) ProtoMessage()

func (*WorkerHostInfo) ProtoReflect

func (x *WorkerHostInfo) ProtoReflect() protoreflect.Message

func (*WorkerHostInfo) Reset

func (x *WorkerHostInfo) Reset()

func (*WorkerHostInfo) Size

func (val *WorkerHostInfo) Size() int

Size returns the size of the object, in bytes, once serialized

func (*WorkerHostInfo) String

func (x *WorkerHostInfo) String() string

func (*WorkerHostInfo) Unmarshal

func (val *WorkerHostInfo) Unmarshal(buf []byte) error

Unmarshal an object of type WorkerHostInfo from the protobuf v3 wire format

type WorkerInfo

type WorkerInfo struct {
	WorkerHeartbeat *WorkerHeartbeat `protobuf:"bytes,1,opt,name=worker_heartbeat,json=workerHeartbeat,proto3" json:"worker_heartbeat,omitempty"`
	// contains filtered or unexported fields
}

Detailed worker information.

func (*WorkerInfo) Descriptor deprecated

func (*WorkerInfo) Descriptor() ([]byte, []int)

Deprecated: Use WorkerInfo.ProtoReflect.Descriptor instead.

func (*WorkerInfo) Equal

func (this *WorkerInfo) Equal(that interface{}) bool

Equal returns whether two WorkerInfo values are equivalent by recursively comparing the message's fields. For more information see the documentation for https://pkg.go.dev/google.golang.org/protobuf/proto#Equal

func (*WorkerInfo) GetWorkerHeartbeat

func (x *WorkerInfo) GetWorkerHeartbeat() *WorkerHeartbeat

func (*WorkerInfo) Marshal

func (val *WorkerInfo) Marshal() ([]byte, error)

Marshal an object of type WorkerInfo to the protobuf v3 wire format

func (*WorkerInfo) ProtoMessage

func (*WorkerInfo) ProtoMessage()

func (*WorkerInfo) ProtoReflect

func (x *WorkerInfo) ProtoReflect() protoreflect.Message

func (*WorkerInfo) Reset

func (x *WorkerInfo) Reset()

func (*WorkerInfo) Size

func (val *WorkerInfo) Size() int

Size returns the size of the object, in bytes, once serialized

func (*WorkerInfo) String

func (x *WorkerInfo) String() string

func (*WorkerInfo) Unmarshal

func (val *WorkerInfo) Unmarshal(buf []byte) error

Unmarshal an object of type WorkerInfo from the protobuf v3 wire format

type WorkerListInfo added in v1.62.3

type WorkerListInfo struct {

	// Worker identifier, should be unique for the namespace.
	// It is distinct from worker identity, which is not necessarily namespace-unique.
	WorkerInstanceKey string `protobuf:"bytes,1,opt,name=worker_instance_key,json=workerInstanceKey,proto3" json:"worker_instance_key,omitempty"`
	// Worker identity, set by the client, may not be unique.
	// Usually host_name+(user group name)+process_id, but can be overwritten by the user.
	WorkerIdentity string `protobuf:"bytes,2,opt,name=worker_identity,json=workerIdentity,proto3" json:"worker_identity,omitempty"`
	// Task queue this worker is polling for tasks.
	TaskQueue         string                      `protobuf:"bytes,3,opt,name=task_queue,json=taskQueue,proto3" json:"task_queue,omitempty"`
	DeploymentVersion *v1.WorkerDeploymentVersion `protobuf:"bytes,4,opt,name=deployment_version,json=deploymentVersion,proto3" json:"deployment_version,omitempty"`
	SdkName           string                      `protobuf:"bytes,5,opt,name=sdk_name,json=sdkName,proto3" json:"sdk_name,omitempty"`
	SdkVersion        string                      `protobuf:"bytes,6,opt,name=sdk_version,json=sdkVersion,proto3" json:"sdk_version,omitempty"`
	// Worker status. Defined by SDK.
	Status v11.WorkerStatus `protobuf:"varint,7,opt,name=status,proto3,enum=temporal.api.enums.v1.WorkerStatus" json:"status,omitempty"`
	// Worker start time.
	// It can be used to determine worker uptime. (current time - start time)
	StartTime *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// Worker host identifier.
	HostName string `protobuf:"bytes,9,opt,name=host_name,json=hostName,proto3" json:"host_name,omitempty"`
	// Worker grouping identifier. A key to group workers that share the same client+namespace+process.
	// This will be used to build the worker command nexus task queue name:
	// "temporal-sys/worker-commands/{worker_grouping_key}"
	WorkerGroupingKey string `protobuf:"bytes,10,opt,name=worker_grouping_key,json=workerGroupingKey,proto3" json:"worker_grouping_key,omitempty"`
	// Worker process identifier. This id only needs to be unique
	// within one host (so using e.g. a unix pid would be appropriate).
	ProcessId string `protobuf:"bytes,11,opt,name=process_id,json=processId,proto3" json:"process_id,omitempty"`
	// Plugins currently in use by this SDK.
	Plugins []*PluginInfo `protobuf:"bytes,12,rep,name=plugins,proto3" json:"plugins,omitempty"`
	// Storage drivers in use by this SDK.
	Drivers []*StorageDriverInfo `protobuf:"bytes,13,rep,name=drivers,proto3" json:"drivers,omitempty"`
	// contains filtered or unexported fields
}

Limited worker information returned in the list response. When adding fields here, ensure that it is also added to WorkerInfo (as it carries the full worker information).

func (*WorkerListInfo) Descriptor deprecated added in v1.62.3

func (*WorkerListInfo) Descriptor() ([]byte, []int)

Deprecated: Use WorkerListInfo.ProtoReflect.Descriptor instead.

func (*WorkerListInfo) Equal added in v1.62.3

func (this *WorkerListInfo) Equal(that interface{}) bool

Equal returns whether two WorkerListInfo values are equivalent by recursively comparing the message's fields. For more information see the documentation for https://pkg.go.dev/google.golang.org/protobuf/proto#Equal

func (*WorkerListInfo) GetDeploymentVersion added in v1.62.3

func (x *WorkerListInfo) GetDeploymentVersion() *v1.WorkerDeploymentVersion

func (*WorkerListInfo) GetDrivers added in v1.62.3

func (x *WorkerListInfo) GetDrivers() []*StorageDriverInfo

func (*WorkerListInfo) GetHostName added in v1.62.3

func (x *WorkerListInfo) GetHostName() string

func (*WorkerListInfo) GetPlugins added in v1.62.3

func (x *WorkerListInfo) GetPlugins() []*PluginInfo

func (*WorkerListInfo) GetProcessId added in v1.62.3

func (x *WorkerListInfo) GetProcessId() string

func (*WorkerListInfo) GetSdkName added in v1.62.3

func (x *WorkerListInfo) GetSdkName() string

func (*WorkerListInfo) GetSdkVersion added in v1.62.3

func (x *WorkerListInfo) GetSdkVersion() string

func (*WorkerListInfo) GetStartTime added in v1.62.3

func (x *WorkerListInfo) GetStartTime() *timestamppb.Timestamp

func (*WorkerListInfo) GetStatus added in v1.62.3

func (x *WorkerListInfo) GetStatus() v11.WorkerStatus

func (*WorkerListInfo) GetTaskQueue added in v1.62.3

func (x *WorkerListInfo) GetTaskQueue() string

func (*WorkerListInfo) GetWorkerGroupingKey added in v1.62.3

func (x *WorkerListInfo) GetWorkerGroupingKey() string

func (*WorkerListInfo) GetWorkerIdentity added in v1.62.3

func (x *WorkerListInfo) GetWorkerIdentity() string

func (*WorkerListInfo) GetWorkerInstanceKey added in v1.62.3

func (x *WorkerListInfo) GetWorkerInstanceKey() string

func (*WorkerListInfo) Marshal added in v1.62.3

func (val *WorkerListInfo) Marshal() ([]byte, error)

Marshal an object of type WorkerListInfo to the protobuf v3 wire format

func (*WorkerListInfo) ProtoMessage added in v1.62.3

func (*WorkerListInfo) ProtoMessage()

func (*WorkerListInfo) ProtoReflect added in v1.62.3

func (x *WorkerListInfo) ProtoReflect() protoreflect.Message

func (*WorkerListInfo) Reset added in v1.62.3

func (x *WorkerListInfo) Reset()

func (*WorkerListInfo) Size added in v1.62.3

func (val *WorkerListInfo) Size() int

Size returns the size of the object, in bytes, once serialized

func (*WorkerListInfo) String added in v1.62.3

func (x *WorkerListInfo) String() string

func (*WorkerListInfo) Unmarshal added in v1.62.3

func (val *WorkerListInfo) Unmarshal(buf []byte) error

Unmarshal an object of type WorkerListInfo from the protobuf v3 wire format

type WorkerPollerInfo

type WorkerPollerInfo struct {

	// Number of polling RPCs that are currently in flight.
	CurrentPollers         int32                  `protobuf:"varint,1,opt,name=current_pollers,json=currentPollers,proto3" json:"current_pollers,omitempty"`
	LastSuccessfulPollTime *timestamppb.Timestamp `` /* 131-byte string literal not displayed */
	// Set true if the number of concurrent pollers is auto-scaled
	IsAutoscaling bool `protobuf:"varint,3,opt,name=is_autoscaling,json=isAutoscaling,proto3" json:"is_autoscaling,omitempty"`
	// contains filtered or unexported fields
}

func (*WorkerPollerInfo) Descriptor deprecated

func (*WorkerPollerInfo) Descriptor() ([]byte, []int)

Deprecated: Use WorkerPollerInfo.ProtoReflect.Descriptor instead.

func (*WorkerPollerInfo) Equal

func (this *WorkerPollerInfo) Equal(that interface{}) bool

Equal returns whether two WorkerPollerInfo values are equivalent by recursively comparing the message's fields. For more information see the documentation for https://pkg.go.dev/google.golang.org/protobuf/proto#Equal

func (*WorkerPollerInfo) GetCurrentPollers

func (x *WorkerPollerInfo) GetCurrentPollers() int32

func (*WorkerPollerInfo) GetIsAutoscaling

func (x *WorkerPollerInfo) GetIsAutoscaling() bool

func (*WorkerPollerInfo) GetLastSuccessfulPollTime

func (x *WorkerPollerInfo) GetLastSuccessfulPollTime() *timestamppb.Timestamp

func (*WorkerPollerInfo) Marshal

func (val *WorkerPollerInfo) Marshal() ([]byte, error)

Marshal an object of type WorkerPollerInfo to the protobuf v3 wire format

func (*WorkerPollerInfo) ProtoMessage

func (*WorkerPollerInfo) ProtoMessage()

func (*WorkerPollerInfo) ProtoReflect

func (x *WorkerPollerInfo) ProtoReflect() protoreflect.Message

func (*WorkerPollerInfo) Reset

func (x *WorkerPollerInfo) Reset()

func (*WorkerPollerInfo) Size

func (val *WorkerPollerInfo) Size() int

Size returns the size of the object, in bytes, once serialized

func (*WorkerPollerInfo) String

func (x *WorkerPollerInfo) String() string

func (*WorkerPollerInfo) Unmarshal

func (val *WorkerPollerInfo) Unmarshal(buf []byte) error

Unmarshal an object of type WorkerPollerInfo from the protobuf v3 wire format

type WorkerSlotsInfo

type WorkerSlotsInfo struct {

	// Number of slots available for the worker to specific tasks.
	// May be -1 if the upper bound is not known.
	CurrentAvailableSlots int32 `` /* 127-byte string literal not displayed */
	// Number of slots used by the worker for specific tasks.
	CurrentUsedSlots int32 `protobuf:"varint,2,opt,name=current_used_slots,json=currentUsedSlots,proto3" json:"current_used_slots,omitempty"`
	// Kind of the slot supplier, which is used to determine how the slots are allocated.
	// Possible values: "Fixed | ResourceBased | Custom String"
	SlotSupplierKind string `protobuf:"bytes,3,opt,name=slot_supplier_kind,json=slotSupplierKind,proto3" json:"slot_supplier_kind,omitempty"`
	// Total number of tasks processed (completed both successfully and unsuccesfully, or any other way)
	// by the worker since the worker started. This is a cumulative counter.
	TotalProcessedTasks int32 `protobuf:"varint,4,opt,name=total_processed_tasks,json=totalProcessedTasks,proto3" json:"total_processed_tasks,omitempty"`
	// Total number of failed tasks processed by the worker so far.
	TotalFailedTasks int32 `protobuf:"varint,5,opt,name=total_failed_tasks,json=totalFailedTasks,proto3" json:"total_failed_tasks,omitempty"`
	// Number of tasks processed in since the last heartbeat from the worker.
	// This is a cumulative counter, and it is reset to 0 each time the worker sends a heartbeat.
	// Contains both successful and failed tasks.
	LastIntervalProcessedTasks int32 `` /* 144-byte string literal not displayed */
	// Number of failed tasks processed since the last heartbeat from the worker.
	LastIntervalFailureTasks int32 `` /* 138-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*WorkerSlotsInfo) Descriptor deprecated

func (*WorkerSlotsInfo) Descriptor() ([]byte, []int)

Deprecated: Use WorkerSlotsInfo.ProtoReflect.Descriptor instead.

func (*WorkerSlotsInfo) Equal

func (this *WorkerSlotsInfo) Equal(that interface{}) bool

Equal returns whether two WorkerSlotsInfo values are equivalent by recursively comparing the message's fields. For more information see the documentation for https://pkg.go.dev/google.golang.org/protobuf/proto#Equal

func (*WorkerSlotsInfo) GetCurrentAvailableSlots

func (x *WorkerSlotsInfo) GetCurrentAvailableSlots() int32

func (*WorkerSlotsInfo) GetCurrentUsedSlots

func (x *WorkerSlotsInfo) GetCurrentUsedSlots() int32

func (*WorkerSlotsInfo) GetLastIntervalFailureTasks

func (x *WorkerSlotsInfo) GetLastIntervalFailureTasks() int32

func (*WorkerSlotsInfo) GetLastIntervalProcessedTasks

func (x *WorkerSlotsInfo) GetLastIntervalProcessedTasks() int32

func (*WorkerSlotsInfo) GetSlotSupplierKind

func (x *WorkerSlotsInfo) GetSlotSupplierKind() string

func (*WorkerSlotsInfo) GetTotalFailedTasks

func (x *WorkerSlotsInfo) GetTotalFailedTasks() int32

func (*WorkerSlotsInfo) GetTotalProcessedTasks

func (x *WorkerSlotsInfo) GetTotalProcessedTasks() int32

func (*WorkerSlotsInfo) Marshal

func (val *WorkerSlotsInfo) Marshal() ([]byte, error)

Marshal an object of type WorkerSlotsInfo to the protobuf v3 wire format

func (*WorkerSlotsInfo) ProtoMessage

func (*WorkerSlotsInfo) ProtoMessage()

func (*WorkerSlotsInfo) ProtoReflect

func (x *WorkerSlotsInfo) ProtoReflect() protoreflect.Message

func (*WorkerSlotsInfo) Reset

func (x *WorkerSlotsInfo) Reset()

func (*WorkerSlotsInfo) Size

func (val *WorkerSlotsInfo) Size() int

Size returns the size of the object, in bytes, once serialized

func (*WorkerSlotsInfo) String

func (x *WorkerSlotsInfo) String() string

func (*WorkerSlotsInfo) Unmarshal

func (val *WorkerSlotsInfo) Unmarshal(buf []byte) error

Unmarshal an object of type WorkerSlotsInfo from the protobuf v3 wire format

Jump to